@@ -27,7 +27,9 @@ from ubiquity import misc
 class Language(FilteredCommand):
     def prepare(self):
         self.language_question = None
-        questions = ['^languagechooser/language-name']
+        self.db.set('localechooser/alreadyrun', 'false')
+        questions = ['^languagechooser/language-name',
+                     '^countrychooser/shortlist$']
         return (['/usr/lib/ubiquity/localechooser/localechooser'], questions,
                 {'PATH': '/usr/lib/ubiquity/localechooser:' + os.environ['PATH']})
 
@@ -35,6 +37,8 @@ class Language(FilteredCommand):
         if question.startswith('languagechooser/language-name'):
             self.language_question = question
 
+            # Get index of untranslated value; we'll map this to the
+            # translated value later.
             current_language_index = self.value_index(
                 'languagechooser/language-name')
             current_language = "English"
@@ -47,13 +51,18 @@ class Language(FilteredCommand):
                 'languagechooser/language-name')
 
             language_codes = {}
-            languagelist = open('/usr/share/localechooser/languagelist')
+            languagelist = open('/usr/lib/ubiquity/localechooser/languagelist')
             for line in languagelist:
                 if line.startswith('#'):
                     continue
                 bits = line.split(';')
-                if len(bits) >= 4:
-                    language_codes[bits[0]] = bits[3]
+                if len(bits) >= 3:
+                    if bits[2] in ('dz', 'km'):
+                        # Exclude these languages for now, as we don't ship
+                        # fonts for them and we don't have sufficient
+                        # translations anyway.
+                        continue
+                    language_codes[bits[0]] = bits[2]
             languagelist.close()
 
             language_display_map = {}
@@ -79,6 +88,14 @@ class Language(FilteredCommand):
                                                language_display_map)
             self.frontend.set_language(current_language)
 
+        elif question == 'countrychooser/shortlist':
+            if 'DEBCONF_USE_CDEBCONF' not in os.environ:
+                # Normally this default is handled by Default-$LL, but since
+                # we can't change debconf's language on the fly (unlike
+                # cdebconf), we have to fake it.
+                self.db.set(question, self.db.get('debian-installer/country'))
+            return True
+
         return super(Language, self).run(priority, question)
 
     def ok_handler(self):
