@@ -21,44 +21,40 @@ import os
 import shutil
 from ubiquity.filteredcommand import FilteredCommand
 from ubiquity.parted_server import PartedServer
-from ubiquity.components.partman import Partman
 
-class PartmanCommit(Partman):
+class PartmanCommit(FilteredCommand):
+    def __init__(self, frontend=None, manual_input=False, get_summary=False):
+        super(PartmanCommit, self).__init__(frontend)
+        self.manual_input = manual_input
+        self.get_summary = get_summary
+
     def prepare(self):
-        # Make sure autopartitioning doesn't get run. We rely on the manual
-        # partitioning control path.
-        shutil.rmtree('/var/lib/partman', ignore_errors=True)
-        if not os.path.exists('/var/lib/partman'):
-            os.makedirs('/var/lib/partman')
-        initial_auto = open('/var/lib/partman/initial_auto', 'w')
-        initial_auto.close()
-
-        questions = ['^partman/choose_partition$',
-                     '^partman/confirm.*',
+        questions = ['^partman/confirm.*',
                      'type:boolean',
                      'ERROR',
                      'PROGRESS']
-        return ('/bin/partman', questions,
-                {'PARTMAN_UPDATE_BEFORE_CONFIRM': '1'})
+        if self.manual_input:
+            env = {'PARTMAN_UPDATE_BEFORE_COMMIT': '1'}
+        else:
+            env = {}
+        return ('/bin/partman-commit', questions, env)
 
     def error(self, priority, question):
-        self.frontend.error_dialog(self.description(question))
+        self.frontend.error_dialog(self.description(question),
+                                   self.extended_description(question))
         self.succeeded = False
         # Unlike a normal error handler, we want to force exit.
         self.done = True
         return True
 
-    def run(self, priority, question):
-        try:
-            qtype = self.db.metaget(question, 'Type')
-        except debconf.DebconfError:
-            qtype = ''
-
-        if question == 'partman/choose_partition':
-            if self.done:
-                # user answered confirmation question, or an error occurred
-                return False
+    # This is, uh, an "inventive" way to spot when partman-commit has
+    # finished starting up parted_server so that we can feed information
+    # into it.
+    def progress_stop(self, progress_title):
+        ret = super(PartmanCommit, self).progress_stop(progress_title)
 
+        if (progress_title == 'partman/progress/init/title' and
+            self.manual_input):
             partitions = {}
             parted = PartedServer()
             for disk in parted.disks():
@@ -72,7 +68,7 @@ class PartmanCommit(Partman):
                 (disk, p_id) = partitions[device]
                 parted.select_disk(disk)
                 if device in mountpoints:
-                    (path, format, fstype) = mountpoints[device]
+                    (path, format, fstype, flags) = mountpoints[device]
                     if path == 'swap':
                         parted.write_part_entry(p_id, 'method', 'swap\n')
                         if format:
@@ -81,28 +77,43 @@ class PartmanCommit(Partman):
                             parted.remove_part_entry(p_id, 'format')
                         parted.remove_part_entry(p_id, 'use_filesystem')
                     else:
-                        detected = parted.has_part_entry(
-                            p_id, 'detected_filesystem')
-                        if fstype is None:
-                            if detected:
-                                fstype = parted.readline_part_entry(
-                                    p_id, 'detected_filesystem')
-                            else:
-                                fstype = 'ext3'
-
-                        if format or not detected:
+                        if (fstype == 'hfs' and
+                            flags is not None and 'boot' in flags):
+                            parted.write_part_entry(
+                                p_id, 'method', 'newworld\n')
+                            parted.write_part_entry(
+                                p_id, 'filesystem', 'newworld')
+                            parted.remove_part_entry(p_id, 'format')
+                            path = None
+                        elif format:
                             parted.write_part_entry(p_id, 'method', 'format\n')
                             parted.write_part_entry(p_id, 'format', '')
+                            if fstype is None:
+                                if parted.has_part_entry(
+                                        p_id, 'detected_filesystem'):
+                                    fstype = parted.readline_part_entry(
+                                        p_id, 'detected_filesystem')
+                                else:
+                                    # TODO cjwatson 2006-09-27: Why don't we
+                                    # know the filesystem type? Fortunately,
+                                    # we have an explicit indication from
+                                    # the user that it's OK to format this
+                                    # filesystem.
+                                    fstype = 'ext3'
                             parted.write_part_entry(p_id, 'filesystem', fstype)
                             parted.remove_part_entry(p_id, 'options')
                             parted.mkdir_part_entry(p_id, 'options')
                         else:
                             parted.write_part_entry(p_id, 'method', 'keep\n')
                             parted.remove_part_entry(p_id, 'format')
-                            parted.write_part_entry(
-                                p_id, 'detected_filesystem', fstype)
+                            if fstype is not None:
+                                parted.write_part_entry(
+                                    p_id, 'detected_filesystem', fstype)
                         parted.write_part_entry(p_id, 'use_filesystem', '')
-                        parted.write_part_entry(p_id, 'mountpoint', path)
+                        if path is not None:
+                            parted.write_part_entry(p_id, 'mountpoint', path)
+                        else:
+                            parted.remove_part_entry(p_id, 'mountpoint')
                 elif (parted.has_part_entry(p_id, 'method') and
                       parted.readline_part_entry(p_id, 'method') == 'newworld'):
                     # Leave existing newworld boot partitions alone.
@@ -112,25 +123,30 @@ class PartmanCommit(Partman):
                     parted.remove_part_entry(p_id, 'format')
                     parted.remove_part_entry(p_id, 'use_filesystem')
 
-            # Don't preseed_as_c, because Perl debconf is buggy in that it
-            # doesn't expand variables in the result of METAGET choices-c.
-            # All locales have the same variables anyway so it doesn't
-            # matter.
-            self.preseed('partman/choose_partition',
-                         self.description('partman/text/end_the_partitioning'))
-            self.current_question = question
-            return True
+        return ret
 
-        elif question.startswith('partman/confirm'):
-            self.current_question = question
-            if self.frontend.confirm_partitioning_dialog(
-                    self.description(question), self.confirmation_message()):
-                self.preseed(question, 'true')
-                self.succeeded = True
+    def run(self, priority, question):
+        if self.done:
+            return self.succeeded
+
+        try:
+            qtype = self.db.metaget(question, 'Type')
+        except debconf.DebconfError:
+            qtype = ''
+
+        if question.startswith('partman/confirm'):
+            if question == 'partman/confirm':
+                self.db.set('ubiquity/partman-made-changes', 'true')
             else:
+                self.db.set('ubiquity/partman-made-changes', 'false')
+            # If we're being run to get the partitioning summary, then stop
+            # here.
+            if self.get_summary:
                 self.preseed(question, 'false')
                 self.succeeded = False
-            self.done = True
+                self.done = True
+            else:
+                self.preseed(question, 'true')
             return True
 
         elif qtype == 'boolean':
@@ -157,8 +173,4 @@ class PartmanCommit(Partman):
             return True
 
         else:
-            return super(Partman, self).run(priority, question)
-
-    # Partman's ok_handler isn't appropriate here.
-    def ok_handler(self):
-        return super(Partman, self).ok_handler()
+            return super(PartmanCommit, self).run(priority, question)
