@@ -114,10 +114,6 @@ def check_mountpoint(mountpoints, size):
         if path == 'newworld':
             result.remove(MOUNTPOINT_NONEWWORLD)
             continue
-        elif fstype is None:
-            # Some other special-purpose partition we don't know about for
-            # whatever reason.
-            continue
 
         if path == '/':
             root = True
@@ -125,13 +121,14 @@ def check_mountpoint(mountpoints, size):
         elif '/'.join(path.split('/')[:2]) in ('/boot', '/usr', '/var'):
             root_size += float(size[device.split('/')[2]])
 
-        if path != 'swap' and path in seen_mountpoints:
-            result.add(MOUNTPOINT_DUPPATH)
-        else:
-            seen_mountpoints.add(path)
-        regex = re.compile(r'^[a-zA-Z0-9/\-\_\+]+$')
-        if not regex.search(path):
-            result.add(MOUNTPOINT_BADCHAR)
+        if path.startswith('/'):
+            if path in seen_mountpoints:
+                result.add(MOUNTPOINT_DUPPATH)
+            else:
+                seen_mountpoints.add(path)
+            regex = re.compile(r'^[a-zA-Z0-9/\-\_\+]+$')
+            if not regex.search(path):
+                result.add(MOUNTPOINT_BADCHAR)
 
         if fstype == 'xfs':
             if path == '/':
@@ -139,7 +136,7 @@ def check_mountpoint(mountpoints, size):
             elif path == '/boot':
                 xfs_boot = True
 
-        if not format:
+        if path.startswith('/') and not format:
             pathtop = '/'.join(path.split('/')[:2])
             if (pathtop in ('/', '/boot', '/usr', '/var') and
                 path not in ('/usr/local', '/var/local')):
